@@ -17,5 +17,7 @@ def to_json(ctx, path, workers):
     spinner.succeed(f"Found dir: {path}\n ")
 
     # Conversion
-    convert_to_json(path, services.extractor_endpoint, services.token, workers)
+    convert_to_json(
+        path, services.extractor_endpoint, services.token, workers, services.headers
+    )
     spinner.succeed("Converted invoice(s) to ocr json output.")
