@@ -50,14 +50,14 @@ def run_requests(workers: int, path: str, services) -> dict:
 
                     result[idx] = flatten_invoice(extracted_invoice, validated_invoice,)
                 except Exception as e:
-                    result[idx] = {"error_message": (repr(e), None, None)}
+                    result[idx] = {"error_message": (str(e), None, None)}
                 finally:
                     result[idx]["file_name"] = (file_name, None, None)
 
                 bar.update(1)
 
     if not result:
-        quit(f"No files found in path")
+        quit("No files found in path")
     return (result, vat_validation_result)
 
 
@@ -95,8 +95,13 @@ def flatten_invoice(invoice, validation):
                         )
                 # ibanAll enc
                 elif all(isinstance(list_item, str) for list_item in v):
-                    for counter, list_item in enumerate(v):
-                        _dict[f"{k}_{counter+1}_idx"] = (list_item, None, None)
+                    if v:
+                        _dict[k] = []
+                        for _, list_item in enumerate(v):
+                            _dict[k].append(list_item)
+                        _dict[k] = (", ".join(_dict[k]), None, None)
+                    else:
+                        _dict[k] = ("", None, None)
                 # Undefined datastructure
                 else:
                     pass
@@ -114,14 +119,22 @@ def flatten_invoice(invoice, validation):
 
                 if probabilities and original_k in probabilities:
                     if probabilities[original_k]:
-                        _dict[field_name] = (v, probabilities[original_k], None)
+                        _dict[field_name] = (
+                            v if v else "",
+                            probabilities[original_k],
+                            None,
+                        )
                     else:
-                        _dict[field_name] = (v, None, None)
+                        _dict[field_name] = (v if v else "", None, None)
                 else:
-                    _dict[field_name] = (v, None, None)
+                    _dict[field_name] = (v if v else "", None, None)
                 if validation:
                     if original_k in validation:
-                        _dict[field_name] = (v, None, validation[original_k])
+                        _dict[field_name] = (
+                            v if v else "",
+                            None,
+                            validation[original_k],
+                        )
 
     traverse_items(entities, probabilities, validation, return_dict)
     return return_dict
