@@ -22,20 +22,14 @@ def request_token(token_endpoint, username, password):
 
 @handle_status_code
 def extract_invoice(
-    file,
-    extractor_endpoint,
-    content_type,
-    token=None,
-    params=("rasterization: true", "probabilities: true"),
+    file, extractor_endpoint, content_type, token=None, params=None, timeout=1800,
 ):
     """ Request invoice extractor """
     response = requests.post(
         url=extractor_endpoint,
         data=file,
-        params={x.split(":")[0].strip(): x.split(":")[1].strip() for x in params}
-        if params
-        else params,
-        timeout=1800,
+        params=params,
+        timeout=timeout,
         headers={"Content-type": content_type, "Authorization": f"Bearer {token}"},
     )
 
